@@ -12,155 +12,43 @@
 
 #endif
 
+#include <string.h>
+
 #include <algorithm>
 #include <iostream>
-#include <string.h>
 
 using namespace std;
 using namespace Eigen;
 
-#ifndef R_BUILD
-Eigen::MatrixXd Pointer2MatrixXd(double *x, int x_row, int x_col)
-{
-    Eigen::MatrixXd x_matrix(x_row, x_col);
-    int i, j;
-    for (i = 0; i < x_row; i++)
-    {
-        for (j = 0; j < x_col; j++)
-        {
-            x_matrix(i, j) = x[i * x_col + j];
-        }
-    }
-    return x_matrix;
-}
-
-// Eigen::MatrixXi Pointer2MatrixXi(int *x, int x_row, int x_col)
-// {
-//     Eigen::MatrixXi x_matrix(x_row, x_col);
-//     int i, j;
-//     for (i = 0; i < x_row; i++)
-//     {
-//         for (j = 0; j < x_col; j++)
-//         {
-//             x_matrix(i, j) = x[i * x_col + j];
-//         }
-//     }
-//     return x_matrix;
-// }
-
-Eigen::VectorXd Pointer2VectorXd(double *x, int x_len)
-{
-    Eigen::VectorXd x_vector(x_len);
-    int i;
-    for (i = 0; i < x_len; i++)
-    {
-        x_vector[i] = x[i];
-    }
-    return x_vector;
-}
-
-Eigen::VectorXi Pointer2VectorXi(int *x, int x_len)
-{
-    Eigen::VectorXi x_vector(x_len);
-    int i;
-    for (i = 0; i < x_len; i++)
-    {
-        x_vector[i] = x[i];
-    }
-    return x_vector;
-}
-
-void MatrixXd2Pointer(Eigen::MatrixXd x_matrix, double *x)
-{
-    int x_matrix_row, x_matrix_col, i, j;
-    x_matrix_row = x_matrix.rows();
-    x_matrix_col = x_matrix.cols();
-    for (i = 0; i < x_matrix_row; i++)
-    {
-        for (j = 0; j < x_matrix_col; j++)
-        {
-            x[i * x_matrix_col + j] = x_matrix(i, j);
-        }
-    }
-    return;
-}
-
-// void MatrixXi2Pointer(Eigen::MatrixXi x_matrix, int *x)
-// {
-//     int x_matrix_row, x_matrix_col, i, j;
-//     x_matrix_row = x_matrix.rows();
-//     x_matrix_col = x_matrix.cols();
-//     for (i = 0; i < x_matrix_row; i++)
-//     {
-//         for (j = 0; j < x_matrix_col; j++)
-//         {
-//             x[i * x_matrix_col + j] = x_matrix(i, j);
-//         }
-//     }
-// }
-
-void VectorXd2Pointer(Eigen::VectorXd x_vector, double *x)
-{
-    int x_matrix_len, i;
-    x_matrix_len = x_vector.size();
-
-    for (i = 0; i < x_matrix_len; i++)
-    {
-        x[i] = x_vector[i];
-    }
-    return;
-}
-
-// void VectorXi2Pointer(Eigen::VectorXi x_vector, int *x)
-// {
-//     int x_matrix_len, i;
-//     x_matrix_len = x_vector.size();
-
-//     for (i = 0; i < x_matrix_len; i++)
-//     {
-//         x[i] = x_vector[i];
-//     }
-// }
-#endif
-
-Eigen::VectorXi find_ind(Eigen::VectorXi &L, Eigen::VectorXi &index, Eigen::VectorXi &gsize, int beta_size, int N)
-{
-    if (L.size() == N)
-    {
+Eigen::VectorXi find_ind(Eigen::VectorXi &L, Eigen::VectorXi &gindex, Eigen::VectorXi &gsize, int beta_size, int N) {
+    if (L.size() == N) {
         return Eigen::VectorXi::LinSpaced(beta_size, 0, beta_size - 1);
-    }
-    else
-    {
+    } else {
         int mark = 0;
         Eigen::VectorXi ind = Eigen::VectorXi::Zero(beta_size);
 
-        for (int i = 0; i < L.size(); i++)
-        {
-            ind.segment(mark, gsize(L(i))) = Eigen::VectorXi::LinSpaced(gsize(L(i)), index(L(i)), index(L(i)) + gsize(L(i)) - 1);
+        for (int i = 0; i < L.size(); i++) {
+            ind.segment(mark, gsize(L(i))) =
+                Eigen::VectorXi::LinSpaced(gsize(L(i)), gindex(L(i)), gindex(L(i)) + gsize(L(i)) - 1);
             mark = mark + gsize(L(i));
         }
         return ind.head(mark).eval();
     }
 }
 
-Eigen::Matrix<Eigen::MatrixXd, -1, -1> invPhi(Eigen::Matrix<Eigen::MatrixXd, -1, -1> &Phi, int N)
-{
+Eigen::Matrix<Eigen::MatrixXd, -1, -1> invPhi(Eigen::Matrix<Eigen::MatrixXd, -1, -1> &Phi, int N) {
     Eigen::Matrix<Eigen::MatrixXd, -1, -1> invPhi(N, 1);
     int row;
-    for (int i = 0; i < N; i++)
-    {
+    for (int i = 0; i < N; i++) {
         row = (Phi(i, 0)).rows();
         invPhi(i, 0) = (Phi(i, 0)).ldlt().solve(Eigen::MatrixXd::Identity(row, row));
     }
     return invPhi;
 }
 
-void slice_assignment(Eigen::VectorXd &nums, Eigen::VectorXi &ind, double value)
-{
-    if (ind.size() != 0)
-    {
-        for (int i = 0; i < ind.size(); i++)
-        {
+void slice_assignment(Eigen::VectorXd &nums, Eigen::VectorXi &ind, double value) {
+    if (ind.size() != 0) {
+        for (int i = 0; i < ind.size(); i++) {
             nums(ind(i)) = value;
         }
     }
@@ -180,13 +68,10 @@ void slice_assignment(Eigen::VectorXd &nums, Eigen::VectorXi &ind, double value)
 //     return sub_nums;
 // }
 
-Eigen::VectorXi vector_slice(Eigen::VectorXi &nums, Eigen::VectorXi &ind)
-{
+Eigen::VectorXi vector_slice(Eigen::VectorXi &nums, Eigen::VectorXi &ind) {
     Eigen::VectorXi sub_nums(ind.size());
-    if (ind.size() != 0)
-    {
-        for (int i = 0; i < ind.size(); i++)
-        {
+    if (ind.size() != 0) {
+        for (int i = 0; i < ind.size(); i++) {
             sub_nums(i) = nums(ind(i));
         }
     }
@@ -251,15 +136,11 @@ Eigen::VectorXi vector_slice(Eigen::VectorXi &nums, Eigen::VectorXi &ind)
 
 // replace B by C in A
 // to do : binary search
-Eigen::VectorXi diff_union(Eigen::VectorXi A, Eigen::VectorXi &B, Eigen::VectorXi &C)
-{
+Eigen::VectorXi diff_union(Eigen::VectorXi A, Eigen::VectorXi &B, Eigen::VectorXi &C) {
     unsigned int k;
-    for (unsigned int i = 0; i < B.size(); i++)
-    {
-        for (k = 0; k < A.size(); k++)
-        {
-            if (B(i) == A(k))
-            {
+    for (unsigned int i = 0; i < B.size(); i++) {
+        for (k = 0; k < A.size(); k++) {
+            if (B(i) == A(k)) {
                 A(k) = C(i);
                 break;
             }
@@ -269,40 +150,26 @@ Eigen::VectorXi diff_union(Eigen::VectorXi A, Eigen::VectorXi &B, Eigen::VectorX
     return A;
 }
 
-Eigen::VectorXi min_k(Eigen::VectorXd &vec, int k, bool sort_by_value)
-{
-    Eigen::VectorXi ind = Eigen::VectorXi::LinSpaced(vec.size(), 0, vec.size() - 1); //[0 1 2 3 ... N-1]
-    auto rule = [vec](int i, int j) -> bool
-    {
-        return vec(i) < vec(j);
-    }; // sort rule
+Eigen::VectorXi min_k(Eigen::VectorXd &vec, int k, bool sort_by_value) {
+    Eigen::VectorXi ind = Eigen::VectorXi::LinSpaced(vec.size(), 0, vec.size() - 1);  // [0 1 2 3 ... N-1]
+    auto rule = [vec](int i, int j) -> bool { return vec(i) < vec(j); };              // sort rule
     std::nth_element(ind.data(), ind.data() + k, ind.data() + ind.size(), rule);
-    if (sort_by_value)
-    {
+    if (sort_by_value) {
         std::sort(ind.data(), ind.data() + k, rule);
-    }
-    else
-    {
+    } else {
         std::sort(ind.data(), ind.data() + k);
     }
 
     return ind.head(k).eval();
 }
 
-Eigen::VectorXi max_k(Eigen::VectorXd &vec, int k, bool sort_by_value)
-{
-    Eigen::VectorXi ind = Eigen::VectorXi::LinSpaced(vec.size(), 0, vec.size() - 1); //[0 1 2 3 ... N-1]
-    auto rule = [vec](int i, int j) -> bool
-    {
-        return vec(i) > vec(j);
-    }; // sort rule
+Eigen::VectorXi max_k(Eigen::VectorXd &vec, int k, bool sort_by_value) {
+    Eigen::VectorXi ind = Eigen::VectorXi::LinSpaced(vec.size(), 0, vec.size() - 1);  // [0 1 2 3 ... N-1]
+    auto rule = [vec](int i, int j) -> bool { return vec(i) > vec(j); };              // sort rule
     std::nth_element(ind.data(), ind.data() + k, ind.data() + ind.size(), rule);
-    if (sort_by_value)
-    {
+    if (sort_by_value) {
         std::sort(ind.data(), ind.data() + k, rule);
-    }
-    else
-    {
+    } else {
         std::sort(ind.data(), ind.data() + k);
     }
     return ind.head(k).eval();
@@ -320,39 +187,28 @@ Eigen::VectorXi max_k(Eigen::VectorXd &vec, int k, bool sort_by_value)
 //     return ind.head(k).eval();
 // }
 
-// Ac
-Eigen::VectorXi Ac(Eigen::VectorXi &A, int N)
-{
+// complement
+Eigen::VectorXi complement(Eigen::VectorXi &A, int N) {
     int A_size = A.size();
-    if (A_size == 0)
-    {
+    if (A_size == 0) {
         return Eigen::VectorXi::LinSpaced(N, 0, N - 1);
-    }
-    else if (A_size == N)
-    {
+    } else if (A_size == N) {
         Eigen::VectorXi I(0);
         return I;
-    }
-    else
-    {
+    } else {
         Eigen::VectorXi I(N - A_size);
         int cur_index = 0;
         int A_index = 0;
-        for (int i = 0; i < N; i++)
-        {
-            if (A_index >= A_size)
-            {
+        for (int i = 0; i < N; i++) {
+            if (A_index >= A_size) {
                 I(cur_index) = i;
                 cur_index += 1;
                 continue;
             }
-            if (i != A(A_index))
-            {
+            if (i != A(A_index)) {
                 I(cur_index) = i;
                 cur_index += 1;
-            }
-            else
-            {
+            } else {
                 A_index += 1;
             }
         }
@@ -396,43 +252,30 @@ Eigen::VectorXi Ac(Eigen::VectorXi &A, int N)
 //     }
 // }
 
-void slice(Eigen::VectorXd &nums, Eigen::VectorXi &ind, Eigen::VectorXd &A, int axis)
-{
-    if (ind.size() == 0)
-    {
+void slice(Eigen::VectorXd &nums, Eigen::VectorXi &ind, Eigen::VectorXd &A, int axis) {
+    if (ind.size() == 0) {
         A = Eigen::VectorXd::Zero(0);
-    }
-    else
-    {
+    } else {
         A = Eigen::VectorXd::Zero(ind.size());
-        for (int i = 0; i < ind.size(); i++)
-        {
+        for (int i = 0; i < ind.size(); i++) {
             A(i) = nums(ind(i));
         }
     }
     return;
 }
 
-void slice(Eigen::MatrixXd &nums, Eigen::VectorXi &ind, Eigen::MatrixXd &A, int axis)
-{
-    if (axis == 0)
-    {
+void slice(Eigen::MatrixXd &nums, Eigen::VectorXi &ind, Eigen::MatrixXd &A, int axis) {
+    if (axis == 0) {
         A = Eigen::MatrixXd::Zero(ind.size(), nums.cols());
-        if (ind.size() != 0)
-        {
-            for (int i = 0; i < ind.size(); i++)
-            {
+        if (ind.size() != 0) {
+            for (int i = 0; i < ind.size(); i++) {
                 A.row(i) = nums.row(ind(i));
             }
         }
-    }
-    else
-    {
+    } else {
         A = Eigen::MatrixXd::Zero(nums.rows(), ind.size());
-        if (ind.size() != 0)
-        {
-            for (int i = 0; i < ind.size(); i++)
-            {
+        if (ind.size() != 0) {
+            for (int i = 0; i < ind.size(); i++) {
                 A.col(i) = nums.col(ind(i));
             }
         }
@@ -440,33 +283,24 @@ void slice(Eigen::MatrixXd &nums, Eigen::VectorXi &ind, Eigen::MatrixXd &A, int
     return;
 }
 
-void slice(Eigen::SparseMatrix<double> &nums, Eigen::VectorXi &ind, Eigen::SparseMatrix<double> &A, int axis)
-{
-    if (axis == 0)
-    {
-
+void slice(Eigen::SparseMatrix<double> &nums, Eigen::VectorXi &ind, Eigen::SparseMatrix<double> &A, int axis) {
+    if (axis == 0) {
         Eigen::SparseMatrix<double, Eigen::RowMajor> nums_row(nums);
         Eigen::SparseMatrix<double, Eigen::RowMajor> A_row(ind.size(), nums.cols());
         A_row.reserve(nums.nonZeros());
 
-        if (ind.size() != 0)
-        {
-            for (int i = 0; i < ind.size(); i++)
-            {
+        if (ind.size() != 0) {
+            for (int i = 0; i < ind.size(); i++) {
                 A_row.row(i) = nums_row.row(ind(i));
             }
         }
 
         A = A_row;
-    }
-    else
-    {
+    } else {
         A.resize(nums.rows(), ind.size());
         A.reserve(nums.nonZeros());
-        if (ind.size() != 0)
-        {
-            for (int i = 0; i < ind.size(); i++)
-            {
+        if (ind.size() != 0) {
+            for (int i = 0; i < ind.size(); i++) {
                 A.col(i) = nums.col(ind(i));
             }
         }
@@ -474,43 +308,30 @@ void slice(Eigen::SparseMatrix<double> &nums, Eigen::VectorXi &ind, Eigen::Spars
     return;
 }
 
-void slice_restore(Eigen::VectorXd &A, Eigen::VectorXi &ind, Eigen::VectorXd &nums, int axis)
-{
-    if (ind.size() == 0)
-    {
+void slice_restore(Eigen::VectorXd &A, Eigen::VectorXi &ind, Eigen::VectorXd &nums, int axis) {
+    if (ind.size() == 0) {
         nums = Eigen::VectorXd::Zero(nums.size());
-    }
-    else
-    {
+    } else {
         nums = Eigen::VectorXd::Zero(nums.size());
-        for (int i = 0; i < ind.size(); i++)
-        {
+        for (int i = 0; i < ind.size(); i++) {
             nums(ind(i)) = A(i);
         }
     }
     return;
 }
 
-void slice_restore(Eigen::MatrixXd &A, Eigen::VectorXi &ind, Eigen::MatrixXd &nums, int axis)
-{
-    if (axis == 0)
-    {
+void slice_restore(Eigen::MatrixXd &A, Eigen::VectorXi &ind, Eigen::MatrixXd &nums, int axis) {
+    if (axis == 0) {
         nums = Eigen::MatrixXd::Zero(nums.rows(), nums.cols());
-        if (ind.size() != 0)
-        {
-            for (int i = 0; i < ind.size(); i++)
-            {
+        if (ind.size() != 0) {
+            for (int i = 0; i < ind.size(); i++) {
                 nums.row(ind(i)) = A.row(i);
             }
         }
-    }
-    else
-    {
+    } else {
         nums = Eigen::MatrixXd::Zero(nums.rows(), nums.cols());
-        if (ind.size() != 0)
-        {
-            for (int i = 0; i < ind.size(); i++)
-            {
+        if (ind.size() != 0) {
+            for (int i = 0; i < ind.size(); i++) {
                 nums.col(ind(i)) = A.col(i);
             }
         }
@@ -518,39 +339,30 @@ void slice_restore(Eigen::MatrixXd &A, Eigen::VectorXi &ind, Eigen::MatrixXd &nu
     return;
 }
 
-void coef_set_zero(int p, int M, Eigen::VectorXd &beta, double &coef0)
-{
+void coef_set_zero(int p, int M, Eigen::VectorXd &beta, double &coef0) {
     beta = Eigen::VectorXd::Zero(p);
     coef0 = 0.;
     return;
 }
 
-void coef_set_zero(int p, int M, Eigen::MatrixXd &beta, Eigen::VectorXd &coef0)
-{
+void coef_set_zero(int p, int M, Eigen::MatrixXd &beta, Eigen::VectorXd &coef0) {
     beta = Eigen::MatrixXd::Zero(p, M);
     coef0 = Eigen::VectorXd::Zero(M);
     return;
 }
 
-Eigen::VectorXd array_product(Eigen::VectorXd &A, Eigen::VectorXd &B, int axis)
-{
+Eigen::VectorXd array_product(Eigen::VectorXd &A, Eigen::VectorXd &B, int axis) {
     A = A.array() * B.array();
     return A;
 }
 
-Eigen::MatrixXd array_product(Eigen::MatrixXd &A, Eigen::VectorXd &B, int axis)
-{
-    if (axis == 0)
-    {
-        for (int i = 0; i < A.rows(); i++)
-        {
+Eigen::MatrixXd array_product(Eigen::MatrixXd &A, Eigen::VectorXd &B, int axis) {
+    if (axis == 0) {
+        for (int i = 0; i < A.rows(); i++) {
             A.row(i) = A.row(i).array() * B.array();
         }
-    }
-    else
-    {
-        for (int i = 0; i < A.cols(); i++)
-        {
+    } else {
+        for (int i = 0; i < A.cols(); i++) {
             A.col(i) = A.col(i).array() * B.array();
         }
     }
@@ -566,39 +378,26 @@ Eigen::MatrixXd array_product(Eigen::MatrixXd &A, Eigen::VectorXd &B, int axis)
 //     return A;
 // }
 
-void array_quotient(Eigen::VectorXd &A, Eigen::VectorXd &B, int axis)
-{
+void array_quotient(Eigen::VectorXd &A, Eigen::VectorXd &B, int axis) {
     A = A.array() / B.array();
     return;
 }
-void array_quotient(Eigen::MatrixXd &A, Eigen::VectorXd &B, int axis)
-{
-    if (axis == 0)
-    {
-        for (int i = 0; i < A.rows(); i++)
-        {
+void array_quotient(Eigen::MatrixXd &A, Eigen::VectorXd &B, int axis) {
+    if (axis == 0) {
+        for (int i = 0; i < A.rows(); i++) {
             A.row(i) = A.row(i).array() / B.array();
         }
-    }
-    else
-    {
-        for (int i = 0; i < A.cols(); i++)
-        {
+    } else {
+        for (int i = 0; i < A.cols(); i++) {
             A.col(i) = A.col(i).array() / B.array();
         }
     }
     return;
 }
 
-double matrix_dot(Eigen::VectorXd &A, Eigen::VectorXd &B)
-{
-    return A.dot(B);
-}
+double matrix_dot(Eigen::VectorXd &A, Eigen::VectorXd &B) { return A.dot(B); }
 
-Eigen::VectorXd matrix_dot(Eigen::MatrixXd &A, Eigen::VectorXd &B)
-{
-    return A.transpose() * B;
-}
+Eigen::VectorXd matrix_dot(Eigen::MatrixXd &A, Eigen::VectorXd &B) { return A.transpose() * B; }
 
 // void matrix_sqrt(Eigen::MatrixXd &A, Eigen::MatrixXd &B)
 // {
@@ -620,7 +419,8 @@ Eigen::VectorXd matrix_dot(Eigen::MatrixXd &A, Eigen::VectorXd &B)
 //         //     << "MatrixSqrt failed with negative eigenvalues: "
 //         //     << eigenvalues.transpose();
 
-//         B = adjoint_eigen_solver.eigenvectors() * (adjoint_eigen_solver.eigenvalues().cwiseSqrt().asDiagonal()) * adjoint_eigen_solver.eigenvectors().transpose();
+//         B = adjoint_eigen_solver.eigenvectors() * (adjoint_eigen_solver.eigenvalues().cwiseSqrt().asDiagonal()) *
+//         adjoint_eigen_solver.eigenvectors().transpose();
 //         //    .cwiseMax(Eigen::Matrix<FloatType, N, 1>::Zero()) //R.cwiseMax(P)
 //         //    .cwiseSqrt()  // R.cwiseSqrt()
 //         //    .asDiagonal() * // x.asDiagonal()
@@ -628,16 +428,13 @@ Eigen::VectorXd matrix_dot(Eigen::MatrixXd &A, Eigen::VectorXd &B)
 //     }
 // }
 
-void add_constant_column(Eigen::MatrixXd &X)
-{
+void add_constant_column(Eigen::MatrixXd &X) {
     X.col(0) = Eigen::MatrixXd::Ones(X.rows(), 1);
     return;
 }
 
-void add_constant_column(Eigen::SparseMatrix<double> &X)
-{
-    for (int i = 0; i < X.rows(); i++)
-    {
+void add_constant_column(Eigen::SparseMatrix<double> &X) {
+    for (int i = 0; i < X.rows(); i++) {
         X.insert(i, 0) = 1.0;
     }
     return;
@@ -653,7 +450,8 @@ void add_constant_column(Eigen::SparseMatrix<double> &X)
 //     X.reserve(x.nonZeros() + x.rows());
 // }
 
-// void overload_ldlt(Eigen::SparseMatrix<double> &X_new, Eigen::SparseMatrix<double> &X, Eigen::VectorXd &Z, Eigen::VectorXd &beta)
+// void overload_ldlt(Eigen::SparseMatrix<double> &X_new, Eigen::SparseMatrix<double> &X, Eigen::VectorXd &Z,
+// Eigen::VectorXd &beta)
 // {
 //     // Eigen::SparseMatrix<double> XTX = X_new.transpose() * X;
 
@@ -665,7 +463,8 @@ void add_constant_column(Eigen::SparseMatrix<double> &X)
 //     return;
 // }
 
-// void overload_ldlt(Eigen::SparseMatrix<double> &X_new, Eigen::SparseMatrix<double> &X, Eigen::MatrixXd &Z, Eigen::MatrixXd &beta)
+// void overload_ldlt(Eigen::SparseMatrix<double> &X_new, Eigen::SparseMatrix<double> &X, Eigen::MatrixXd &Z,
+// Eigen::MatrixXd &beta)
 // {
 //     // Eigen::SparseMatrix<double> XTX = X_new.transpose() * X;
 
@@ -700,34 +499,27 @@ void add_constant_column(Eigen::SparseMatrix<double> &X)
 // }
 
 // to do
-void add_weight(Eigen::MatrixXd &x, Eigen::VectorXd &y, Eigen::VectorXd weights)
-{
+void add_weight(Eigen::MatrixXd &x, Eigen::VectorXd &y, Eigen::VectorXd weights) {
     Eigen::VectorXd sqrt_weight = weights.array().sqrt();
     int n = x.rows();
-    for (int i = 0; i < n; i++)
-    {
+    for (int i = 0; i < n; i++) {
         x.row(i) = x.row(i) * sqrt_weight(i);
     }
     array_product(y, sqrt_weight, 1);
 };
 
-void add_weight(Eigen::MatrixXd &x, Eigen::MatrixXd &y, Eigen::VectorXd weights)
-{
+void add_weight(Eigen::MatrixXd &x, Eigen::MatrixXd &y, Eigen::VectorXd weights) {
     Eigen::VectorXd sqrt_weight = weights.array().sqrt();
     int n = x.rows();
-    for (int i = 0; i < n; i++)
-    {
+    for (int i = 0; i < n; i++) {
         x.row(i) = x.row(i) * sqrt_weight(i);
     }
     array_product(y, sqrt_weight, 1);
 };
 
-void add_weight(Eigen::SparseMatrix<double> &x, Eigen::VectorXd &y, Eigen::VectorXd weights)
-{
-    for (int k = 0; k < x.outerSize(); ++k)
-    {
-        for (SparseMatrix<double>::InnerIterator it(x, k); it; ++it)
-        {
+void add_weight(Eigen::SparseMatrix<double> &x, Eigen::VectorXd &y, Eigen::VectorXd weights) {
+    for (int k = 0; k < x.outerSize(); ++k) {
+        for (SparseMatrix<double>::InnerIterator it(x, k); it; ++it) {
             x.coeffRef(int(it.row()), int(it.col())) = x.coeffRef(int(it.row()), int(it.col())) * weights(it.row());
         }
     }
@@ -735,12 +527,9 @@ void add_weight(Eigen::SparseMatrix<double> &x, Eigen::VectorXd &y, Eigen::Vecto
     array_product(y, sqrt_weight, 1);
 };
 
-void add_weight(Eigen::SparseMatrix<double> &x, Eigen::MatrixXd &y, Eigen::VectorXd weights)
-{
-    for (int k = 0; k < x.outerSize(); ++k)
-    {
-        for (SparseMatrix<double>::InnerIterator it(x, k); it; ++it)
-        {
+void add_weight(Eigen::SparseMatrix<double> &x, Eigen::MatrixXd &y, Eigen::VectorXd weights) {
+    for (int k = 0; k < x.outerSize(); ++k) {
+        for (SparseMatrix<double>::InnerIterator it(x, k); it; ++it) {
             x.coeffRef(int(it.row()), int(it.col())) = x.coeffRef(int(it.row()), int(it.col())) * weights(it.row());
         }
     }
