@@ -22,7 +22,7 @@
 #' \code{cortype = 2} denotes the exponential structure,
 #' where the covariance matrix has \eqn{(i,j)} entry equals \eqn{rho^{|i-j|}}.
 #' code{cortype = 3} denotes the constant structure,
-#' where the non-diagnoal entries of covariance
+#' where the non-diagonal entries of covariance
 #' matrix are \eqn{rho} and diagonal entries are 1.
 #' @param snr A numerical value controlling the signal-to-noise ratio (SNR). The SNR is defined as
 #' as the variance of \eqn{x\beta} divided
@@ -109,12 +109,15 @@ generate.data <- function(n,
                           p,
                           support.size = NULL,
                           rho = 0,
-                          family = c("gaussian",
-                                     "binomial",
-                                     "poisson",
-                                     "cox",
-                                     "mgaussian",
-                                     "multinomial"),
+                          family = c(
+                            "gaussian",
+                            "binomial",
+                            "poisson",
+                            "cox",
+                            "mgaussian",
+                            "multinomial",
+                            "gamma"
+                          ),
                           beta = NULL,
                           cortype = 1,
                           snr = 10,
@@ -124,7 +127,7 @@ generate.data <- function(n,
                           class.num = 3,
                           seed = 1) {
   sigma <- 1
-  
+
   family <- match.arg(family)
   if (family == "mgaussian") {
     y_dim <- y.dim
@@ -134,7 +137,7 @@ generate.data <- function(n,
     y_dim <- 1
   }
   y_cor <- diag(y_dim)
-  
+
   set.seed(seed)
   # if(is.null(beta)){
   #   beta <- rep(0, p)
@@ -142,12 +145,12 @@ generate.data <- function(n,
   # } else{
   #   beta <- beta
   # }
-  
+
   multi_y <- FALSE
   if (family %in% c("mgaussian", "multinomial")) {
     multi_y <- TRUE
   }
-  
+
   if (!is.null(beta)) {
     if (multi_y) {
       stopifnot(is.matrix(beta))
@@ -156,7 +159,7 @@ generate.data <- function(n,
       stopifnot(is.vector(beta))
       support.size <- sum(abs(beta) > 1e-5)
     }
-    
+
     beta[abs(beta) <= 1e-5] <- 0
   } else {
     if (is.null(support.size)) {
@@ -164,12 +167,12 @@ generate.data <- function(n,
     }
     stopifnot(is.numeric(support.size) & support.size >= 1)
   }
-  
+
   if (cortype == 1) {
     Sigma <- diag(p)
   } else if (cortype == 2) {
     Sigma <- matrix(0, p, p)
-    Sigma <- rho ^ (abs(row(Sigma) - col(Sigma)))
+    Sigma <- rho^(abs(row(Sigma) - col(Sigma)))
   } else if (cortype == 3) {
     Sigma <- matrix(rho, p, p)
     diag(Sigma) <- 1
@@ -179,7 +182,7 @@ generate.data <- function(n,
   } else {
     x <- MASS::mvrnorm(n, rep(0, p), Sigma)
   }
-  
+
   ### pre-treatment for beta ###
   input_beta <- beta
   if (multi_y) {
@@ -198,7 +201,7 @@ generate.data <- function(n,
       beta <- input_beta
     }
     sigma <- sqrt((t(beta) %*% Sigma %*% beta) / snr)
-    
+
     y <- x %*% beta + rnorm(n, 0, sigma)
   }
   if (family == "binomial") {
@@ -209,7 +212,7 @@ generate.data <- function(n,
       beta <- input_beta
     }
     sigma <- sqrt((t(beta) %*% Sigma %*% beta) / snr)
-    
+
     eta <- x %*% beta + rnorm(n, 0, sigma)
     PB <- apply(eta, 1, generatedata2)
     y <- stats::rbinom(n, 1, PB)
@@ -222,10 +225,10 @@ generate.data <- function(n,
       beta <- input_beta
     }
     sigma <- sqrt((t(beta) %*% Sigma %*% beta) / snr)
-    
+
     eta <- x %*% beta + rnorm(n, 0, sigma)
     time <-
-      (-log(stats::runif(n)) / drop(exp(eta))) ^ (1 / weibull.shape)
+      (-log(stats::runif(n)) / drop(exp(eta)))^(1 / weibull.shape)
     ctime <- stats::runif(n, max = uniform.max)
     status <- (time < ctime) * 1
     censoringrate <- 1 - mean(status)
@@ -237,7 +240,7 @@ generate.data <- function(n,
     m <- 5 * sqrt(2 * log(p) / n)
     # m <- sigma * sqrt(2 * log(p) / n) / 3
     if (is.null(input_beta)) {
-      beta[nonzero] <- stats::runif(support.size,-2 * m, 2 * m)
+      beta[nonzero] <- stats::runif(support.size, -2 * m, 2 * m)
       # beta[nonzero] <- stats::rnorm(support.size, sd = m)
     } else {
       beta <- input_beta
@@ -246,7 +249,7 @@ generate.data <- function(n,
     sigma <- 0
     eta <- x %*% beta + stats::rnorm(n, 0, sigma)
     eta <- ifelse(eta > 30, 30, eta)
-    eta <- ifelse(eta < -30,-30, eta)
+    eta <- ifelse(eta < -30, -30, eta)
     eta <- exp(eta)
     # eta[eta<0.0001] <- 0.0001
     # eta[eta>1e5] <- 1e5
@@ -257,8 +260,9 @@ generate.data <- function(n,
     m <- 5 * sqrt(2 * log(p) / n)
     M <- 100 * m
     if (is.null(input_beta)) {
-      beta[nonzero,] <- matrix(stats::runif(support.size * y_dim, m, M),
-                               ncol = y_dim)
+      beta[nonzero, ] <- matrix(stats::runif(support.size * y_dim, m, M),
+        ncol = y_dim
+      )
     } else {
       beta <- input_beta
     }
@@ -266,9 +270,11 @@ generate.data <- function(n,
     sigma <- diag(sigma)
     sigma <- sigma * y_cor
     epsilon <-
-      MASS::mvrnorm(n = n,
-                    mu = rep(0, y_dim),
-                    Sigma = sigma)
+      MASS::mvrnorm(
+        n = n,
+        mu = rep(0, y_dim),
+        Sigma = sigma
+      )
     y <- x %*% beta + epsilon
     colnames(y) <- paste0("y", 1:y_dim)
   }
@@ -276,8 +282,9 @@ generate.data <- function(n,
     m <- 5 * sqrt(2 * log(p) / n)
     M <- 100 * m
     if (is.null(input_beta)) {
-      beta[nonzero,] <- matrix(stats::runif(support.size * y_dim, m, M),
-                               ncol = y_dim)
+      beta[nonzero, ] <- matrix(stats::runif(support.size * y_dim, m, M),
+        ncol = y_dim
+      )
     } else {
       beta <- input_beta
     }
@@ -289,15 +296,31 @@ generate.data <- function(n,
     prob_y <- exp(prob_y)
     prob_y <-
       sweep(prob_y,
-            MARGIN = 1,
-            STATS = rowSums(prob_y),
-            FUN = "/")
+        MARGIN = 1,
+        STATS = rowSums(prob_y),
+        FUN = "/"
+      )
     y <- apply(prob_y, 1, function(x) {
       sample(0:2, size = 1, prob = x)
     })
   }
+  if (family == "gamma") {
+    m <- 5 * sqrt(2 * log(p) / n)
+    if (is.null(input_beta)) {
+      # TODO
+      beta[nonzero] <- stats::runif(support.size, m, 100 * m)
+    } else {
+      beta <- input_beta
+    }
+    sigma <- sqrt((t(beta) %*% Sigma %*% beta) / snr)
+    eta <- x %*% beta + stats::rnorm(n, 0, sigma)
+    eta <- abs(eta)
+    # TODO the shape para of gamma is uniform in [0.1,100.1]
+    shape_para <- 100 * runif(n) + 0.1
+    y <- stats::rgamma(n, shape = shape_para, rate = shape_para * eta)
+  }
   set.seed(NULL)
-  
+
   colnames(x) <- paste0("x", 1:p)
   return(list(x = x, y = y, beta = beta))
 }
@@ -322,7 +345,7 @@ generate.data <- function(n,
 #' \code{cortype = 2} denotes the exponential structure,
 #' where the covariance matrix has \eqn{(i,j)} entry equals \eqn{rho^{|i-j|}}.
 #' code{cortype = 3} denotes the constant structure,
-#' where the non-diagnoal entries of covariance
+#' where the non-diagonal entries of covariance
 #' matrix are \eqn{rho} and diagonal entries are 1.
 #' @param weibull.shape The shape parameter of the Weibull distribution.
 #' It works only when \code{family = "cox"}.
@@ -408,17 +431,17 @@ generate.group <- function(n,
   family <- match.arg(family)
   set.seed(seed)
   group.index <- rep(1:J, each = k)
-  
+
   if (is.null(support.size)) {
     stop("Please provide an integer to support.size.")
   }
   stopifnot(is.numeric(support.size) & support.size >= 1)
-  
+
   if (cortype == 1) {
     Sigma <- diag(J)
   } else if (cortype == 2) {
     Sigma <- matrix(0, J, J)
-    Sigma <- rho ^ (abs(row(Sigma) - col(Sigma)))
+    Sigma <- rho^(abs(row(Sigma) - col(Sigma)))
   } else if (cortype == 3) {
     Sigma <- matrix(rho, J, J)
     diag(Sigma) <- 1
@@ -451,7 +474,7 @@ generate.group <- function(n,
   if (family == "cox") {
     eta <- x %*% beta + rnorm(n, 0, sigma1)
     time <-
-      (-log(stats::runif(n)) / drop(exp(eta))) ^ (1 / weibull.shape)
+      (-log(stats::runif(n)) / drop(exp(eta)))^(1 / weibull.shape)
     ctime <- stats::runif(n, max = uniform.max)
     status <- (time < ctime) * 1
     censoringrate <- 1 - mean(status)
@@ -461,12 +484,12 @@ generate.group <- function(n,
   if (family == "poisson") {
     eta <- x %*% beta + stats::rnorm(n, 0, sigma1)
     eta <- ifelse(eta > 50, 50, eta)
-    eta <- ifelse(eta < -50,-50, eta)
+    eta <- ifelse(eta < -50, -50, eta)
     eta <- exp(eta)
     y <- sapply(eta, stats::rpois, n = 1)
   }
   set.seed(NULL)
-  
+
   colnames(x) <- paste0("x", 1:(J * k))
   return(list(
     x = x,
@@ -512,9 +535,10 @@ generatedata2 <- function(eta) {
 
 list.beta <- function(beta.mat, object, sparse) {
   beta.all <- matrix(0,
-                     nrow = length(object[["best.model"]][["beta"]]),
-                     ncol = ncol(beta.mat))
-  beta.all[object[["screening.index"]],] <- beta.mat[[1]]
+    nrow = length(object[["best.model"]][["beta"]]),
+    ncol = ncol(beta.mat)
+  )
+  beta.all[object[["screening.index"]], ] <- beta.mat[[1]]
   if (sparse) {
     beta.all <- Matrix::Matrix(beta.all)
   }
@@ -547,8 +571,10 @@ abess_model_matrix <- function(object,
     deparse2 <- function(x) {
       paste(deparse(x, width.cutoff = 500L), collapse = " ")
     }
-    reorder <- match(vapply(attr(t, "variables"), deparse2, "")[-1L],
-                     names(data))
+    reorder <- match(
+      vapply(attr(t, "variables"), deparse2, "")[-1L],
+      names(data)
+    )
     if (anyNA(reorder)) {
       stop("model frame and formula mismatch in model.matrix()")
     }
@@ -559,7 +585,7 @@ abess_model_matrix <- function(object,
   ############################################################
   if (length(data)) {
     namD <- names(data)
-    
+
     for (i in namD) {
       if (is.character(data[[i]])) {
         stop(
